@@ -1,21 +1,21 @@
 /*  XFC: Xfce Foundation Classes (Core Library)
- *  Copyright (C) 2004 The XFC Development Team.
+ *  Copyright (C) 2004-2005 The XFC Development Team.
  *
  *  utfstring.cc - Standard string compatible UTF-8 string implementation
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
  */
  
 #include "utfstring.hh"
@@ -1114,7 +1114,7 @@ std::string
 String::convert(const char *to_codeset, G::Error *error)
 {
 	gsize bytes_written = 0;
-	char *s = g_convert(data(), size(), to_codeset, "UTF-8", 0, &bytes_written, *error);
+	char *s = g_convert(data(), (gssize)size(), to_codeset, "UTF-8", 0, &bytes_written, *error);
 	std::string tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
@@ -1124,7 +1124,7 @@ String
 String::convert(const std::string& str, const char *from_codeset, G::Error *error)
 {
 	gsize bytes_written = 0;
-	char *s = g_convert(str.c_str(), str.size(), "UTF-8", from_codeset, 0, &bytes_written, *error);
+	char *s = g_convert(str.c_str(), (gssize)str.size(), "UTF-8", from_codeset, 0, &bytes_written, *error);
 	String tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
@@ -1134,7 +1134,7 @@ std::string
 String::convert_with_fallback(const char *to_codeset, G::Error *error)
 {
 	gsize bytes_written = 0;
-	char *s = g_convert_with_fallback(data(), size(), to_codeset, "UTF-8", 0, 0, &bytes_written, *error);
+	char *s = g_convert_with_fallback(data(), (gssize)size(), to_codeset, "UTF-8", 0, 0, &bytes_written, *error);
 	std::string tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
@@ -1144,7 +1144,7 @@ std::string
 String::convert_with_fallback(const char *to_codeset, const char *fallback, G::Error *error)
 {
 	gsize bytes_written = 0;
-	char *s = g_convert_with_fallback(data(), size(), to_codeset, "UTF-8", const_cast<char*>(fallback), 0, &bytes_written, *error);
+	char *s = g_convert_with_fallback(data(), (gssize)size(), to_codeset, "UTF-8", const_cast<char*>(fallback), 0, &bytes_written, *error);
 	std::string tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
@@ -1154,7 +1154,7 @@ String
 String::convert_with_fallback(const std::string& str, const char *from_codeset, G::Error *error)
 {
 	gsize bytes_written = 0;
-	char *s = g_convert_with_fallback(str.c_str(), str.size(), "UTF-8", from_codeset, 0, 0, &bytes_written, *error);
+	char *s = g_convert_with_fallback(str.c_str(), (gssize)str.size(), "UTF-8", from_codeset, 0, 0, &bytes_written, *error);
 	String tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
@@ -1164,7 +1164,7 @@ String
 String::convert_with_fallback(const std::string& str, const char *from_codeset, const char *fallback, G::Error *error)
 {
 	gsize bytes_written = 0;
-	char *s = g_convert_with_fallback(str.c_str(), str.size(), "UTF-8", from_codeset, const_cast<char*>(fallback), 0, &bytes_written, *error);
+	char *s = g_convert_with_fallback(str.c_str(), (gssize)str.size(), "UTF-8", from_codeset, const_cast<char*>(fallback), 0, &bytes_written, *error);
 	String tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
@@ -1174,7 +1174,7 @@ String
 String::from_locale(const std::string& opsysstring, G::Error *error)
 {
 	gsize bytes_written = 0;
-	char *s = g_locale_to_utf8(opsysstring.data(), opsysstring.size(), 0, &bytes_written, *error);
+	char *s = g_locale_to_utf8(opsysstring.data(), (gssize)opsysstring.size(), 0, &bytes_written, *error);
 	String tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
@@ -1184,7 +1184,7 @@ std::string
 String::to_locale(G::Error *error) const
 {
 	gsize bytes_written = 0;
-	char *s = g_locale_from_utf8(data(), size(), 0, &bytes_written, *error);
+	char *s = g_locale_from_utf8(data(), (gssize)size(), 0, &bytes_written, *error);
 	std::string tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
@@ -1194,7 +1194,7 @@ String
 String::from_filename(const std::string& opsysstring, G::Error *error)
 {
 	gsize bytes_written = 0;
-	char *s = g_filename_to_utf8(opsysstring.data(), opsysstring.size(), 0, &bytes_written, *error);
+	char *s = g_filename_to_utf8(opsysstring.data(), (gssize)opsysstring.size(), 0, &bytes_written, *error);
 	String tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
@@ -1204,7 +1204,7 @@ std::string
 String::to_filename(G::Error *error) const
 {
 	gsize bytes_written = 0;
-	char *s = g_filename_from_utf8(data(), size(), 0, &bytes_written, *error);
+	char *s = g_filename_from_utf8(data(), (gssize)size(), 0, &bytes_written, *error);
 	std::string tmp_str(s, bytes_written);
 	g_free(s);
 	return tmp_str;
